package tests.javaee;

import ejbs.CascadePersistRemote;
import entities.Course;
import entities.Student;
import java.util.HashSet;
import java.util.Set;
import javax.naming.InitialContext;

public class TestCascadePersist {
    
    private static int STUDENT_ID1 = 420;
    private static String STD_NAME1 = "Charsoubees";
    private static int STUDENT_ID2 = 421;
    private static String STD_NAME2 = "CharsouIkkis";
    private static int STUDENT_ID3 = 422;
    private static String STD_NAME3 = "CharsouBais";
    
    private static  int MATH_ID = 104;
    private static String MATH_COURSE = "Math";
    private static  int CHEM_ID = 204;
    private static String CHEM_COURSE = "Chemistry";

    private CascadePersistRemote remoteObj;
    
    public TestCascadePersist() {
    }
    
    public void test() {
        try {
            remoteObj = (CascadePersistRemote) new InitialContext().lookup("ejbs.CascadePersistRemote");
            persistRelationship();
            assertRelationshipPersisted();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private void persistRelationship() {
        Course mathCourse = createCourse(MATH_ID, MATH_COURSE);
        Course chemCourse = createCourse(CHEM_ID, CHEM_COURSE);
        Student student1 = createStudent(STUDENT_ID1, STD_NAME1);
        student1.addCourse(mathCourse);
        student1.addCourse(chemCourse);
        Student student2 = createStudent(STUDENT_ID2, STD_NAME2);
        student2.addCourse(mathCourse);
        Student student3 = createStudent(STUDENT_ID3, STD_NAME3);
        student3.addCourse(chemCourse);
        
        Set mathStudents = new HashSet();
        mathStudents.add(student1);
        mathStudents.add(student2);
        Set chemStudents = new HashSet();
        chemStudents.add(student3);
        chemStudents.add(student1);
        
        mathCourse.setStudents(mathStudents);
        chemCourse.setStudents(chemStudents);
        
        remoteObj.persistCourse(mathCourse);
        remoteObj.persistCourse(chemCourse);
    }
    
    private void assertRelationshipPersisted() throws Exception {
        
        Course retrievedMath = remoteObj.getCourse(MATH_ID);
        Course retrievedChem = remoteObj.getCourse(CHEM_ID);
        
        if (retrievedMath.getStudents().size() == 2 && retrievedChem.getStudents().size() == 2)
            System.out.println("Relationship persisted Correctly");
        else
            System.out.println("Expected many to many relationship between course and student to have been set. " +
                    " Expected 2 students in Math and 2 in Chem, Actual - " + retrievedMath.getStudents().size() + " - " + retrievedChem.getStudents().size());
    }
    
    private Student createStudent(int id, String name) {
        Student student = new Student();
        student.setId(id);
        student.setName(name);
        return student;
    }
    
    private Course createCourse(int id, String courseName) {
        Course course = new Course();
        course.setId(id);
        course.setName(courseName);
        return course;
    }
    
}
